@@ -20,13 +20,13 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <ntqcheckbox.h>
-#include <ntqiconset.h>
-#include <ntqlabel.h>
-#include <ntqlayout.h>
-#include <ntqlineedit.h>
-#include <ntqpushbutton.h>
-#include <ntqspinbox.h>
+#include <tqcheckbox.h>
+#include <tqiconset.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqlineedit.h>
+#include <tqpushbutton.h>
+#include <tqspinbox.h>
 
 #include <tdeconfig.h>
 #include <kdebug.h>
