@@ -20,8 +20,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <ntqdir.h>
-#include <ntqlineedit.h>
+#include <tqdir.h>
+#include <tqlineedit.h>
 
 #include <tdeaction.h>
 #include <tdeapplication.h>
