@@ -46,7 +46,7 @@ int main( int argc, string argv[])
 					  I18N_NOOP( "This program is a complete re-write of one by the same name written by Alexandre\n"
 								 "Sagala. The last version of that program was 0.9 which was released on 2003-03-09\n"
 								 "and targeted the KDE 2.2 and QT 2.3 environments. Unfortunately it does not compile\n"
-								 "on today's KDE / QT environments.\n"
+								 "on today's TDE / TQt environments.\n"
 								 "\n"
 								 "Not to mention that it did not cater for the full set of 'nmap' options. Or, perhaps,\n"
 								 "'nmap' progressed whilst that version of Knmap languished.\n"
