@@ -20,10 +20,10 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <ntqcheckbox.h>
-#include <ntqlabel.h>
-#include <ntqlayout.h>
-#include <ntqlineedit.h>
+#include <tqcheckbox.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqlineedit.h>
 
 #include <kdebug.h>
 #include <tdelocale.h>
